@@ -22,6 +22,7 @@
  ********************************************************************************/
 
 
+#include <R.h>
 #include <math.h>
 #include "rand_pdf.h"
 #include "rand_draws.h"
@@ -32,6 +33,7 @@
 #include "all_draws.h"
 #include "rhelp.h"
 #include <assert.h>
+#include <stdlib.h>
 
 /* constants used below */
 #define GA 1.0 /* 5.0 */
@@ -41,7 +43,6 @@
 #define LINEAR(gamma, min, max, d) min + max / (1.0 + exp(0.0-gamma*(d-0.5)));
 
 /* minimum values for the nugget and s2_g0 */
-#define NUGMIN 1e-10
 #define S2G0MIN 1e-10
 
 
@@ -60,7 +61,7 @@ double **F;
 {
   double **aux1, **Vb;
   double *by;
-  int info;
+  /* int info; */
   
   /* zero out by and b */
   by = new_zero_vector(col); 
@@ -73,7 +74,7 @@ double **F;
   
   /* Vb = inv(F'*F) */
   Vb = new_id_matrix(col);
-  info = linalg_dgesv(col, aux1, Vb);
+  /* info = */ linalg_dgesv(col, aux1, Vb);
   delete_matrix(aux1);
   
   /* by = Z*F */
@@ -107,7 +108,7 @@ double **F, **Ti, **Vb;
 double tau2, itemp;
 {
   double **Vbi, **Fgi;
-  int info;
+  /* int info; */
   unsigned int i, j;
 
   /* sanity check for inv-temperature */
@@ -136,7 +137,7 @@ double tau2, itemp;
   /* Vb = inv(F'*F + Ti/tau2); is inv(aux1) */
   id(Vb, col);
   if(col==1) Vb[0][0] = 1.0/Vbi[0][0];
-  else info = linalg_dgesv(col, Vbi, Vb);
+  else /* info = */ linalg_dgesv(col, Vbi, Vb);
   delete_matrix(Vbi);
   
   /* by = Z*F/(1+g) + b0'*Ti/tau2; 
@@ -219,7 +220,7 @@ double tau2, itemp;
   /* now for lambda */
   lambda = ZZ + b0Tib0 - BVBiB;
   
-  /* myprintf(mystderr, 
+  /* MYprintf(MYstderr, 
      "noK: n=%d, itemp=%g, ZZ=%g, tau2=%g, b0Tib0/tau2=%g, BVBiB=%g, lambda=%g\n", 
      n, itemp, ZZ, tau2, b0Tib0, BVBiB, lambda); */
 
@@ -249,7 +250,7 @@ double **F, **Ki, **Ti, **Vb;
 double tau2, itemp;
 {
   double **KiF, **Vbi;
-  int info;
+  /* int info; */
 
   /* sanity check for temperature */
   assert(itemp >= 0);
@@ -265,8 +266,10 @@ double tau2, itemp;
   
   /* Vb = inv(F'*KiF + Ti/tau2) */
   id(Vb, col);
+  // printMatrix(Vb, col, col, MYstdout);
+  // printMatrix(Vbi, col, col, MYstdout);
   if(col==1) Vb[0][0] = 1.0/Vbi[0][0];
-  else info = linalg_dgesv(col, Vbi, Vb);
+  else /* info = */ linalg_dgesv(col, Vbi, Vb);
   delete_matrix(Vbi);
   
   /* by = Z*KiF + b0'*Ti/tau2 */
@@ -339,7 +342,7 @@ double tau2, itemp;
   /* now for lambda */
   lambda = ZKiZ + b0Tib0/tau2 - BVBiB;
 
-  /* myprintf(mystderr, "n=%d, itemp=%g, ZKiZ=%g, tau2=%g, b0Tib0/tau2=%g, BVBiB=%g, lambda=%g\n", 
+  /* MYprintf(MYstderr, "n=%d, itemp=%g, ZKiZ=%g, tau2=%g, b0Tib0/tau2=%g, BVBiB=%g, lambda=%g\n", 
     n, itemp, ZKiZ, tau2, b0Tib0/tau2, BVBiB, lambda); */
 
   /* this is here because when itemp=0 lambda should be 0, but
@@ -422,7 +425,7 @@ void *state;
   /* s2 = 1/gamrnd(alpha, 1/g, 1) */
   /* return 1.0 / (1.0/g * rgamma(alpha)); */
   inv_gamma_mult_gelman(&x, alpha, g, 1, state);
-  /* myprintf(mystderr, "alpha = %g, beta = %g  =>  x = %g\n", alpha, g, x); */
+  /* MYprintf(MYstderr, "alpha = %g, beta = %g  =>  x = %g\n", alpha, g, x); */
   return x;
 }
 
@@ -796,6 +799,7 @@ void *state;
 
 
 
+
 /*
  * mixture_priors_ratio:
  * 
@@ -1055,7 +1059,7 @@ void *state;
   pdlast = post_margin(n,col,lambda,Vb,log_det_K,a0-m,g0,itemp);
   pdlast += log_d_prior_pdf(dlast, d_alpha, d_beta);
   
-  /* if(lin && pd > pdlast) myprintf(mystderr, "pd=%g, pdlast=%g, qRatio=%g\n",
+  /* if(lin && pd > pdlast) MYprintf(MYstderr, "pd=%g, pdlast=%g, qRatio=%g\n",
      pd, pdlast, qRatio); */
 
   /* compute acceptance prob */
@@ -1319,9 +1323,85 @@ void *state;
   
   /* accept or reject */
   alpha = exp(pnug - pnuglast)*(q_bak/q_fwd);
-  /* myprintf(mystderr, "nug_last=%g -> nug=%g : alpha=%g\n", nuglast, nug, alpha); */
-  if(runi(state) > alpha) { /* myprintf(mystderr, "  -- rejected\n");*/ return nuglast; }
-  else { /*myprintf(mystderr, "  -- accepted\n");*/ return nug; }
+  /* MYprintf(MYstderr, "nug_last=%g -> nug=%g : alpha=%g\n", nuglast, nug, alpha); */
+  if(runi(state) > alpha) { /* MYprintf(MYstderr, "  -- rejected\n");*/ return nuglast; }
+  else { /*MYprintf(MYstderr, "  -- accepted\n");*/ return nug; }
+}
+
+
+/*
+ * nug_draw_twovar:
+ * 
+ * draws for nug given the rest of the parameters
+ * except b and s2 marginalized out
+ *
+ * F[col][n], K[n][n], Kchol[n][n], K_new[n][n], Ti[col][col], T[col][col],
+ * Vb[col][col], Vb_new[col][col], Ki_new[n][n], Kchol_new[n][n] b0[col], Z[n]
+ */
+
+double nug_draw_twovar(n, col, nuglast, F, Z, K, log_det_K, lambda, Vb, 
+  K_new, Ki_new, Kchol_new, log_det_K_new, lambda_new, Vb_new, bmu_new, 
+  b0, Ti, T, tau2, nug_alpha, nug_beta, a0, g0, linear, itemp, 
+  state)
+unsigned int n, col;
+int linear;
+double **F, **K, **K_new, **Ti, **T, **Vb, **Vb_new, **Ki_new, **Kchol_new;
+double *b0, *Z, *log_det_K_new; 
+double nug_alpha[2], nug_beta[2];
+double nuglast, a0, g0, lambda, tau2, log_det_K, itemp;
+double *lambda_new, *bmu_new;
+void *state;
+{
+  double q_fwd, q_bak, nug, pnug, pnuglast, alpha;
+  double *Kdiag;
+  unsigned int i;
+  unsigned int m = 0;
+  
+  /* do nothing if the prior says to fix the nug */
+  if(nug_alpha[0] == 0) return nuglast;
+
+  /* propose new d, and compute proposal probability */
+  /* nug = nug_draw(nuglast, &q_fwd, &q_bak, state); */ /* MODIFIED */
+  nug = unif_propose_pos(nuglast+1.0, &q_fwd, &q_bak, state) - 1.0;
+  
+  /* new covariace matrix based on new nug */
+  if(linear) { /* MODIFIED */
+    // *log_det_K_new = n * log(1.0 + nug);
+    *log_det_K_new = (n/2) * log(1.0) + (n/2) * log(1.0 + nug);
+    // Kdiag = ones(n, 1.0 + nug);
+    Kdiag = ones(n, 1.0);
+    for(i=n/2; i<n; i++) Kdiag[i] += nug;
+    *lambda_new = compute_lambda_noK(Vb_new, bmu_new, n, col, F, Z, Ti, 
+             tau2, b0, Kdiag, itemp);
+    free(Kdiag);
+  } else  { /* MODIFIED */
+    dup_matrix(K_new, K, n, n);
+    // for(i=0; i<n; i++) K_new[i][i] += (nug - nuglast);
+    for(i=n/2; i<n; i++) K_new[i][i] += (nug - nuglast);
+    // inverse_chol(K_new, Ki_new, Kchol_new, n);
+    id(Ki_new, n);
+    for(i=n/2; i<n; i++) Ki_new[i][i] = 1.0 / K_new[i][i];
+    // *log_det_K_new = log_determinant_chol(Kchol_new, n);
+    *log_det_K_new = (n/2) * log(1.0) + (n/2) * log(1.0 + nug);
+    *lambda_new = compute_lambda(Vb_new, bmu_new, n, col, F, Z, Ki_new, 
+         Ti, tau2, b0, itemp);
+  }
+  
+  if(T[0][0] == 0) m = col;
+  
+  /* posteriors */
+  /* pnug = log_nug_prior_pdf(nug, nug_alpha, nug_beta);  MODIFIED */
+  pnug = log_nug_prior_pdf(nug + 1.0 + NUGMIN, nug_alpha, nug_beta);
+  pnug += post_margin(n,col,*lambda_new,Vb_new,*log_det_K_new,a0-m,g0,itemp);
+  /* pnuglast = log_nug_prior_pdf(nuglast, nug_alpha, nug_beta);  MODIFIED */
+  pnuglast = log_nug_prior_pdf(nuglast + 1.0 + NUGMIN, nug_alpha, nug_beta);
+  pnuglast += post_margin(n,col,lambda,Vb,log_det_K,a0-m,g0,itemp);
+  
+  /* accept or reject */
+  alpha = exp(pnug - pnuglast)*(q_bak/q_fwd);
+  /* MYprintf(MYstderr, "nug_last=%g -> nug=%g : alpha=%g\n", nuglast, nug, alpha); */
+  if(runi(state) > alpha) { /* MYprintf(MYstderr, "  -- rejected\n");*/ return nuglast; }
+  else { /*MYprintf(MYstderr, "  -- accepted\n");*/ return nug; }
 }
 
 
@@ -1402,7 +1482,7 @@ void *state;
   
   if(runi(state) > alpha){
     /* printf("nugs %g %g\n",nug, nugfine); */
-    /*printVector(newnugs, 2, mystdout, HUMAN); */
+    /*printVector(newnugs, 2, MYstdout, HUMAN); */
     newnugs[0] = nug;
     newnugs[1] = nugfine;
   }
@@ -1426,7 +1506,7 @@ void *state;
 {
   double **sbb0, **S;
   double *bmb0;
-  int i, nu, info;
+  int i, nu /* , info*/;
   
   /* sbb0 = zeros(length(b0)); */
   sbb0 = new_zero_matrix(col, col);
@@ -1450,7 +1530,7 @@ void *state;
   linalg_daxpy(col*col, rho, *V, 1, *sbb0, 1);
   
   /* then invert: S = inv(sbb0) */
-  info = linalg_dgesv(col, sbb0, S);
+  /* info = */ linalg_dgesv(col, sbb0, S);
   delete_matrix(sbb0);
 
   /* rho parameter */
@@ -1475,7 +1555,7 @@ double *b0, *s2, *mu, *tau2;
 double **b, **Ti, **Ci;
 void *state;
 {
-  int i, info;
+  int i /* , info*/;
   double s2i_sum, s2i;
   double **Vb0i, **Vb0;
   double *b_s2i_sum, *left, *right, *bm;
@@ -1523,7 +1603,7 @@ void *state;
 
   /* first: get the choleski decomposition */
   /* note that this changes the cov variable (Vb0) */
-  info = linalg_dpotrf(col, Vb0);
+  /* info =*/ linalg_dpotrf(col, Vb0);
 
   /* now get the draw using the choleski decomposition */
   mvnrnd(b0, bm, Vb0, col, state);
