@@ -829,6 +829,21 @@ char** ExpSep::TraceNames(unsigned int* len)
 }
 
 
+void ExpSep::Invert(unsigned int n)
+{
+
+  if(! linear) {
+    assert(n == this->n);
+    inverse_chol(K, Ki, Kchol, n);
+    log_det_K = log_determinant_chol(Kchol, n);
+  }
+  else {
+    assert(n > 0);
+    log_det_K = n * log(1.0 + nug);
+  }
+}
+
+
 /*
  * ExpSep_Prior:
  *
