@@ -39,7 +39,7 @@ extern "C"
 #include <math.h>
 #include <stdlib.h>
 #include <assert.h>
-//#include <string.h>
+#include <string.h>
 #include <Rmath.h>
 #include <string>
 #include <fstream>
@@ -575,6 +575,20 @@ double* Matern::Trace(unsigned int* len)
   return trace;
 }
 
+void Matern::Invert(unsigned int n)
+{
+
+  if(! linear) {
+    assert(n == this->n);
+    inverse_chol(K, Ki, Kchol, n);
+    log_det_K = log_determinant_chol(Kchol, n);
+  }
+  else {
+    assert(n > 0);
+    log_det_K = n * log(1.0 + nug);
+  }
+}
+
 
 /*
  * newCorr:
@@ -687,7 +701,7 @@ void Matern_Prior::read_double(double *dparams)
 
   /* starting value for the range parameter */
   d = dparams[1];
-  // myprintf(mystdout, "starting range=%g\n", d);
+  // MYprintf(MYstdout, "starting range=%g\n", d);
 
   /* reset dparams to start after the nugget gamlin params */
   dparams += 13;
@@ -698,7 +712,7 @@ void Matern_Prior::read_double(double *dparams)
 
   /* d hierarchical lambda prior parameters */
   if((int) dparams[0] == -1)
-    { fix_d = true; /*myprintf(mystdout, "fixing d prior\n");*/ }
+    { fix_d = true; /*MYprintf(MYstdout, "fixing d prior\n");*/ }
   else {
     fix_d = false;
     get_mix_prior_params_double(d_alpha_lambda, d_beta_lambda, 
@@ -708,7 +722,7 @@ void Matern_Prior::read_double(double *dparams)
 
   /* read the fixed nu parameter */
   nu = dparams[0];
-  // myprintf(mystdout, "fixed nu=%g\n", nu);
+  // MYprintf(MYstdout, "fixed nu=%g\n", nu);
   dparams += 1; /* reset */
 }
 
@@ -730,7 +744,7 @@ void Matern_Prior::read_ctrlfile(ifstream *ctrlfile)
   /* read the d parameter from the control file */
   ctrlfile->getline(line, BUFFMAX);
   d = atof(strtok(line, " \t\n#"));
-  myprintf(mystdout, "starting d=%g\n", d);
+  MYprintf(MYstdout, "starting d=%g\n", d);
     
   /* read d and nug-hierarchical parameters (mix of gammas) */
   ctrlfile->getline(line, BUFFMAX);
@@ -740,7 +754,7 @@ void Matern_Prior::read_ctrlfile(ifstream *ctrlfile)
   ctrlfile->getline(line, BUFFMAX);
   strcpy(line_copy, line);
   if(!strcmp("fixed", strtok(line_copy, " \t\n#")))
-    { fix_d = true; myprintf(mystdout, "fixing d prior\n"); }
+    { fix_d = true; MYprintf(MYstdout, "fixing d prior\n"); }
   else {
     fix_d = false;
     get_mix_prior_params(d_alpha_lambda, d_beta_lambda, line, "d lambda");  
@@ -749,7 +763,7 @@ void Matern_Prior::read_ctrlfile(ifstream *ctrlfile)
   /* read the (fixed) nu parameter */
   ctrlfile->getline(line, BUFFMAX);
   nu = atof(strtok(line, " \t\n#"));
-  myprintf(mystdout, "fixed nu=%g\n", nu);
+  MYprintf(MYstdout, "fixed nu=%g\n", nu);
 }
 
 
@@ -922,25 +936,25 @@ void Matern_Prior::SetBasePrior(Base_Prior *base_prior)
 
 void Matern_Prior::Print(FILE *outfile)
 {
-  myprintf(mystdout, "corr prior: matern\n");
+  MYprintf(MYstdout, "corr prior: matern\n");
 
   /* print nugget stuff first */
   PrintNug(outfile);
 
   /* range parameter */
-  // myprintf(outfile, "starting d=%g\n", d);
+  // MYprintf(outfile, "starting d=%g\n", d);
 
   /* nu, smoothness parameter */
-  myprintf(mystdout, "fixed nu=%g\n", nu);
+  MYprintf(MYstdout, "fixed nu=%g\n", nu);
 
   /* range gamma prior */
-  myprintf(outfile, "d[a,b][0,1]=[%g,%g],[%g,%g]\n", 
+  MYprintf(outfile, "d[a,b][0,1]=[%g,%g],[%g,%g]\n", 
 	   d_alpha[0], d_beta[0], d_alpha[1], d_beta[1]);
   
   /* range gamma hyperprior */
-  if(fix_d) myprintf(outfile, "d prior fixed\n");
+  if(fix_d) MYprintf(outfile, "d prior fixed\n");
   else {
-    myprintf(mystdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
+    MYprintf(MYstdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
 	     d_alpha_lambda[0], d_beta_lambda[0], d_alpha_lambda[1], 
 	     d_beta_lambda[1]);
   }
